@@ -1,6 +1,7 @@
 from __future__ import print_function
 
 import atexit
+import base64
 import codecs
 import glob
 import json
@@ -36,6 +37,14 @@ HELP_LINKS = [
 
 ] + MetaKernel.help_links
 
+class PDF(object):
+    """Wrapper for PDF object for display.
+    """
+    def __init__(self, filename):
+        with open(filename, 'rb') as f:
+            data = f.read()
+            self._repr_pdf_ = base64.b64encode(data)
+
 
 def get_kernel_json():
     """Get the kernel json for the kernel.
@@ -190,6 +199,9 @@ class OctaveEngine(object):
 
     @plot_settings.setter
     def plot_settings(self, settings):
+        if not self._has_startup:
+            self._default_toolkit = self.eval('graphics_toolkit', silent=True).split()[-1]
+
         settings = settings or dict(backend='inline')
         self._plot_settings = settings
 
@@ -316,6 +328,8 @@ class OctaveEngine(object):
             try:
                 if fname.lower().endswith('.svg'):
                     im = self._handle_svg(filename)
+                elif fname.lower().endswith('.pdf'):
+                    im = PDF(filename)
                 else:
                     im = Image(filename)
                 images.append(im)
